@@ -36,7 +36,9 @@ import os
 import sys
 import tarfile
 import hashlib
+import re
 import zlib
+import shutil
 import tempfile
 import urllib2
 import boto
@@ -164,7 +166,7 @@ class InstallImage(AWSQueryRequest):
             print type+": "+name+" is already installed on the cloud, skipping installation of another one."
             return True
         else:
-            answer = raw_input(type+": "+name+" is already installed on ths cloud. Would you like to use it intead?(y/N)")
+            answer = raw_input(type + ": " + name + " is already installed on this cloud. Would you like to use it instead? (y/N)")
             if (answer=='y' or answer=='Y'):
                 return True
             return False
@@ -183,15 +185,15 @@ class InstallImage(AWSQueryRequest):
             if name_match:
                 if kernel_id=='true' and img.type=='kernel':
                     if self.promptReplace("Kernel", img.name):
-                        ret_id=img.name
+                        ret_id=img.id
                     break
                 elif ramdisk_id=='true' and img.type=='ramdisk':
                     if self.promptReplace("Ramdisk", img.name):
-                        ret_id=img.name
+                        ret_id=img.id
                     break
                 elif kernel_id!='true' and ramdisk_id!='true' and img.type=='machine':
                     if self.promptReplace("Image", img.name):
-                        ret_id=img.name
+                        ret_id=img.id
                     break
 
         if ret_id:
@@ -246,10 +248,10 @@ class InstallImage(AWSQueryRequest):
         try:
             names = bundler.untarzip_image(self.destination, file)
         except OSError:
-            print "Error: cannot unbundle image, possibly corrupted file"
+            print >> sys.stderr, "Error: cannot unbundle image, possibly corrupted file"
             sys.exit(-1)
         except IOError:
-            print "Error: cannot unbundle image, possibly corrupted file"
+            print >> sys.stderr, "Error: cannot unbundle image, possibly corrupted file"
             sys.exit(-1)
         kernel_dir=None
         if not(self.cli_options.kernel_type==None):
@@ -268,14 +270,15 @@ class InstallImage(AWSQueryRequest):
                         if not(kernel_dir) and (os.path.dirname(path) != tar_root):
                             continue;
                         if not name.startswith('.'):
-                            if name.startswith('vmlin'):
+                            # Note that vmlinuz is not always at the beginning of the filename
+                            if name.find('vmlinu') != -1:
                                 print "Bundling/uploading kernel"
                                 if prefix:
                                     name = prefix+name
                                 kernel_id = self.bundleFile(path, name, description, arch, 'true', None)
                                 kernel_found = True
                                 print kernel_id
-                            elif name.startswith('initrd'):
+                            elif re.match(".*(initr(d|amfs)|loader).*", name):
                                 print "Bundling/uploading ramdisk"
                                 if prefix:
                                     name = prefix+name
@@ -283,14 +286,15 @@ class InstallImage(AWSQueryRequest):
                                 print ramdisk_id
                 if not(kernel_found):
                     if not(kernel_dir):
-                        print "Error: couldn't find kernel. Check your parameters or specify an existing kernel/ramdisk"
+                        print >> sys.stderr, "Error: couldn't find kernel. Check your parameters or specify an existing kernel/ramdisk"
                         sys.exit(-1);
                     elif i==0:
-                        print "Error: couldn't find kernel. Check your parameters or specify an existing kernel/ramdisk"
+                        print >> sys.stderr, "Error: couldn't find kernel. Check your parameters or specify an existing kernel/ramdisk"
                         sys.exit(-1);
                 else:
                     break
         #now, install the image, referencing the kernel/ramdisk
+        image_id = None
         for path in names:
             name = os.path.basename(path)
             if not name.startswith('.'):
@@ -301,7 +305,10 @@ class InstallImage(AWSQueryRequest):
                     else:
                         name = name[:-len('.img')]
                     id = self.bundleFile(path, name, description, arch, kernel_id, ramdisk_id)
-                    return id
+                    image_id = id
+        # make good faith attempt to remove working directory and all files within
+        shutil.rmtree(self.destination, True)
+        return image_id
 
     def main(self, **args):
         self.process_args()
@@ -312,30 +319,30 @@ class InstallImage(AWSQueryRequest):
 
         # tarball and image option are mutually exclusive
         if (not(self.cli_options.image_name) and not(self.cli_options.tarball)):
-            print "Error: one of -i or -t must be specified"
+            print >> sys.stderr, "Error: one of -i or -t must be specified"
             sys.exit(-1)
 
         if (self.cli_options.image_name and self.cli_options.tarball):
-            print "Error: -i and -t cannot be specified together"
+            print >> sys.stderr, "Error: -i and -t cannot be specified together"
             sys.exit(-1)
 
         if (self.cli_options.tarball and \
             (not(self.cli_options.description) or not(self.cli_options.architecture))):
-            print "Error: when -t is specified, -s and -a are required"
+            print >> sys.stderr, "Error: when -t is specified, -s and -a are required"
             sys.exit(-1)
 
         if (self.cli_options.architecture and \
             not(self.cli_options.architecture == 'i386' or self.cli_options.architecture == 'x86_64')):
-            print "Error: architecture must be either 'i386' or 'x86_64'"
+            print >> sys.stderr, "Error: architecture must be either 'i386' or 'x86_64'"
             sys.exit(-1)
 
         if (self.cli_options.kernel and not(self.cli_options.ramdisk)) or \
            (not(self.cli_options.kernel) and self.cli_options.ramdisk):
-            print "Error: kernel and ramdisk must both be overridden"
+            print >> sys.stderr, "Error: kernel and ramdisk must both be overridden"
             sys.exit(-1)
 
         if (self.cli_options.architecture and self.cli_options.image_name):
-            print "Warning: you may be overriding the default architecture of this image!"
+            print >> sys.stderr, "Warning: you may be overriding the default architecture of this image!"
 
 
         euare_svc = EuareService()
@@ -346,7 +353,7 @@ class InstallImage(AWSQueryRequest):
                     is_secure=euare_svc.args['is_secure'])
         userinfo  = conn.get_user().arn.split(':')
         if not(userinfo[4]=='eucalyptus') and not(self.cli_options.kernel):
-            print "Error: must be cloud admin to upload kernel/ramdisk. try specifying existing ones with --kernel and --ramdisk"
+            print >> sys.stderr, "Error: must be cloud admin to upload kernel/ramdisk. try specifying existing ones with --kernel and --ramdisk"
             sys.exit(-1)
         self.eustore_url = self.ServiceClass.StoreBaseURL
 
@@ -354,6 +361,8 @@ class InstallImage(AWSQueryRequest):
         ec2_conn = boto.connect_euca(host=euare_svc.args['host'], \
                         aws_access_key_id=euare_svc.args['aws_access_key_id'],\
                         aws_secret_access_key=euare_svc.args['aws_secret_access_key'])
+        ec2_conn.APIVersion = '2012-03-01'
+                        
         self.ImageList = ec2_conn.get_all_images()
 
         if os.environ.has_key('EUSTORE_URL'):
@@ -386,10 +395,12 @@ class InstallImage(AWSQueryRequest):
                     # more param checking now
                     if image['single-kernel']=='True':
                         if self.cli_options.kernel_type:
-                            print "The -k option will be ignored because the image is single-kernel"
+                            print >> sys.stderr, "The -k option will be ignored because the image is single-kernel"
                     else:
-                        if not(self.cli_options.kernel_type):
-                            print "Error: The -k option must be specified because this image has separate kernels"
+                        # Warn about kernel type for multi-kernel images, but not if already installed
+                        # kernel/ramdisk have been specified.
+                        if not(self.cli_options.kernel_type) and not(self.cli_options.kernel):
+                            print >> sys.stderr, "Error: The -k option must be specified because this image has separate kernels"
                             sys.exit(-1)
                     print "Downloading Image : ",image['description']
                     imageURL = self.eustore_url+image['url']
@@ -417,10 +428,9 @@ class InstallImage(AWSQueryRequest):
                     if image['name'] == crc.rjust(10,"0"):
                         print "Installed image: "+self.bundleAll(fp.name, None, image['description'], image['architecture'])
                     else:
-                        print "Error: Downloaded image was incomplete or corrupt, please try again"
-                    os.remove(fp.name)
+                        print >> sys.stderr, "Error: Downloaded image was incomplete or corrupt, please try again"
                 else:
-                    print "Image name not found, please run eustore-describe-images"
+                    print >> sys.stderr, "Image name not found, please run eustore-describe-images"
 
     def main_cli(self):
         euca2ools.utils.print_version_if_necessary()
